@@ -1,5 +1,4 @@
 use crate::error::Result;
-use once_cell::sync::OnceCell;
 use std::fs::{self, File, OpenOptions};
 use std::io;
 use std::path::{Path, PathBuf};
@@ -8,7 +7,7 @@ use std::sync::{Arc, Mutex, MutexGuard, PoisonError};
 use std::thread;
 use std::time::{Duration, SystemTime};
 
-static LOCK: OnceCell<Mutex<()>> = OnceCell::new();
+static LOCK: Mutex<()> = Mutex::new(());
 
 pub(crate) struct Lock {
     intraprocess_guard: Guard,
@@ -43,11 +42,7 @@ impl Lock {
 
 impl Guard {
     fn acquire() -> Self {
-        Guard::Locked(
-            LOCK.get_or_init(|| Mutex::new(()))
-                .lock()
-                .unwrap_or_else(PoisonError::into_inner),
-        )
+        Guard::Locked(LOCK.lock().unwrap_or_else(PoisonError::into_inner))
     }
 }
 
@@ -115,9 +110,8 @@ fn create(path: &Path) -> Option<File> {
             },
         };
 
-        let modified = match metadata.modified() {
-            Ok(modified) => modified,
-            Err(_) => return None,
+        let Ok(modified) = metadata.modified() else {
+            return None;
         };
 
         let now = SystemTime::now();
