@@ -207,14 +207,35 @@
 //! important for a test suite to catch. If the compiler changes something that
 //! makes error messages that we care about substantially worse, it is also
 //! important to catch and report as a compiler issue.
+//!
+//! <br>
+//!
+//! # Troubleshooting
+//!
+//! The Rust compiler's diagnostic output can vary as a function of whether the
+//! `rust-src` Rustup component is installed. The compiler will render source
+//! snippets from the standard library if the standard library source is
+//! available locally, and will simply omit snippets if not. This can account
+//! for differences between CI and local development.
+//!
+//! If you have compile_fail tests pertaining to standard library traits or
+//! types, you can ensure a consistent environment by adding a
+//! rust-toolchain.toml file with the following content.
+//!
+//! ```toml
+//! [toolchain]
+//! components = ["rust-src"]
+//! ```
 
-#![doc(html_root_url = "https://docs.rs/trybuild/1.0.99")]
+#![doc(html_root_url = "https://docs.rs/trybuild/1.0.104")]
+#![cfg_attr(not(check_cfg), allow(unexpected_cfgs))]
 #![allow(
     clippy::collapsible_if,
     clippy::comparison_chain,
     clippy::default_trait_access,
     clippy::derive_partial_eq_without_eq,
     clippy::doc_markdown,
+    clippy::elidable_lifetime_names,
     clippy::enum_glob_use,
     clippy::iter_not_returning_iterator, // https://github.com/rust-lang/rust-clippy/issues/8285
     clippy::let_underscore_untyped, // https://github.com/rust-lang/rust-clippy/issues/10410
@@ -223,6 +244,7 @@
     clippy::module_inception,
     clippy::module_name_repetitions,
     clippy::must_use_candidate,
+    clippy::needless_lifetimes,
     clippy::needless_pass_by_value,
     clippy::non_ascii_literal,
     clippy::range_plus_one,
